%global momorel 1
%global with_wayland 1

Name:          cogl
Version:	1.22.2
Release:       %{momorel}m%{?dist}
Summary:       A library for using 3D graphics hardware to draw pretty pictures

Group:         Development/Libraries
License:       LGPLv2+
URL:           http://www.clutter-project.org/
Source0: http://download.gnome.org/sources/cogl/1.22/cogl-%{version}.tar.xz
NoSource:      0

BuildRequires: cairo-devel
BuildRequires: chrpath
BuildRequires: gdk-pixbuf2-devel
BuildRequires: glib2-devel
BuildRequires: gobject-introspection-devel
BuildRequires: gtk-doc
BuildRequires: libXrandr-devel
BuildRequires: libXcomposite-devel
BuildRequires: libXdamage-devel
BuildRequires: libXext-devel
BuildRequires: libXfixes-devel
BuildRequires: mesa-libGL-devel
BuildRequires: pango-devel
BuildRequires: pkgconfig
BuildRequires: libdrm-devel
BuildRequires: gstreamer1-devel
BuildRequires: gstreamer1-plugins-base-devel

%if %{with_wayland}
BuildRequires: libwayland-server-devel
BuildRequires: libwayland-client-devel
BuildRequires: libwayland-cursor-devel
BuildRequires: libwayland-egl-devel
BuildRequires: libxkbcommon-devel
BuildRequires: mesa-libgbm-devel
%endif


%description
Cogl is a small open source library for using 3D graphics hardware to draw
pretty pictures. The API departs from the flat state machine style of
OpenGL and is designed to make it easy to write orthogonal components that
can render without stepping on each others toes.

As well aiming for a nice API, we think having a single library as opposed
to an API specification like OpenGL has a few advantages too; like being
able to paper over the inconsistencies/bugs of different OpenGL
implementations in a centralized place, not to mention the myriad of OpenGL
extensions. It also means we are in a better position to provide utility
APIs that help software developers since they only need to be implemented
once and there is no risk of inconsistency between implementations.

Having other backends, besides OpenGL, such as drm, Gallium or D3D are
options we are interested in for the future.

%package devel
Summary:       %{name} development environment
Group:         Development/Libraries
Requires:      %{name} = %{version}-%{release}
Requires:      pkgconfig glib2-devel pango-devel cairo-devel
Requires:      mesa-libGL-devel
Requires:      gobject-introspection-devel

%description devel
Header files and libraries for building and developing apps with %{name}.

%package       doc
Summary:       Documentation for %{name}
Group:         Documentation
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch

%description   doc
This package contains documentation for %{name}.

%prep
%setup -q

%build
CFLAGS="$RPM_OPT_FLAGS -fPIC"
%configure \
  --enable-cairo=yes \
  --enable-cogl-pango=yes \
  --enable-cogl-gst \
  --enable-gdk-pixbuf=yes \
  --enable-glx=yes \
  --enable-gtk-doc \
  --enable-introspection=yes \
  --enable-kms-egl-platform \
  --enable-wayland-egl-platform \
  --enable-wayland-egl-server \
  --enable-xlib-egl-platform

make %{?_smp_mflags} V=1

%install
make install DESTDIR=%{buildroot} INSTALL='install -p'

#Remove libtool archives.
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# This gets installed by mistake
rm %{buildroot}%{_datadir}/cogl/examples-data/crate.jpg

# Remove lib64 rpaths
chrpath --delete %{buildroot}%{_libdir}/libcogl-path.so
chrpath --delete %{buildroot}%{_libdir}/libcogl-pango.so
chrpath --delete %{buildroot}%{_libdir}/libcogl-gst.so
chrpath --delete %{buildroot}%{_libdir}/gstreamer-1.0/libgstcogl.so

%find_lang %{name}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%doc COPYING NEWS README ChangeLog
%{_libdir}/libcogl*.so.*
%{_libdir}/girepository-1.0/Cogl*.typelib
%{_libdir}/gstreamer-1.0/libgstcogl.so

%files devel
%{_includedir}/cogl
%{_libdir}/libcogl*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/Cogl*.gir

%files doc
%{_datadir}/gtk-doc/html/cogl
%{_datadir}/gtk-doc/html/cogl-gst
%{_datadir}/gtk-doc/html/cogl-2.0-experimental

%changelog
* Thu Jan 26 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (1.22.0-1m)
- update to 1.22.0

* Wed Feb 25 2015 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (1.20.0-1m)
- update to 1.20.0

* Mon Oct 27 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.18.2-2m)
- enable gst support

* Mon Aug 11 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.18.2-1m)
- update to 1.18.2

* Wed Mar 26 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.18.0-1m)
- update to 1.18.0

* Thu Feb 20 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.17.4-1m)
- update to 1.17.4

* Sat Feb  8 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.17.2-1m)
- update to 1.17.2

* Sun Feb  2 2014 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.16.2-1m)
- update to 1.16.2

* Thu Dec 26 2013 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.16.0-1m)
- update to 1.16.0

* Sat Aug 31 2013 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.15.8-1m)
- update to 1.15.8

* Sun Jun 23 2013 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.14.4-1m)
- update to 1.14.4

* Sat Aug  4 2012 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.10.4-1m)
- update 1.10.4
- temporarily disable gtk-doc support

* Wed Jul  4 2012 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.10.2-1m)
- reimport from fedora

* Tue Jan 24 2012 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.8.2-2m)
- better swrast(mesa) support

* Wed Oct 19 2011 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.8.2-1m)
- update 1.8.2

* Tue Sep 20 2011 Yohsuke Ooi <meke@momonga-linux.org> 
- (1.8.0-1m)
- update 1.8.0

* Sat Sep 10 2011 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.7.8-1m)
- initial build
